#[repr(i32)]pub enum EQueryCvarValueStatus {
ValueIntact = 0,
CvarNotFound = 1,
NotACvar = 2,
CvarProtected = 3,
}Variants
Implementations
Sourceimpl EQueryCvarValueStatus
impl EQueryCvarValueStatus
Sourcepub fn is_valid(value: i32) -> bool
pub fn is_valid(value: i32) -> bool
Returns true if value is a variant of EQueryCvarValueStatus.
Sourcepub fn from_i32(value: i32) -> Option<EQueryCvarValueStatus>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<EQueryCvarValueStatus>
Use the TryFrom<i32> implementation instead
Converts an i32 to a EQueryCvarValueStatus, or None if value is not a valid variant.