#[repr(i32)]pub enum ESplitScreenMessageType {
MsgSplitscreenAdduser = 0,
MsgSplitscreenRemoveuser = 1,
}Variants
Implementations
Sourceimpl ESplitScreenMessageType
impl ESplitScreenMessageType
Sourcepub fn is_valid(value: i32) -> bool
pub fn is_valid(value: i32) -> bool
Returns true if value is a variant of ESplitScreenMessageType.
Sourcepub fn from_i32(value: i32) -> Option<ESplitScreenMessageType>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<ESplitScreenMessageType>
Use the TryFrom<i32> implementation instead
Converts an i32 to a ESplitScreenMessageType, or None if value is not a valid variant.