#[repr(i32)]pub enum ESteamLearnCacheDataResult {
SteamlearnCacheDataError = 0,
SteamlearnCacheDataSuccess = 1,
SteamlearnCacheDataErrorUnknownDataSource = 2,
SteamlearnCacheDataErrorUncachedDataSource = 3,
SteamlearnCacheDataErrorInvalidKeys = 4,
SteamlearnCacheDataErrorForbidden = 5,
SteamlearnCacheDataErrorInvalidTimestamp = 6,
SteamlearnCacheDataDisabled = 7,
}Variants
SteamlearnCacheDataError = 0
SteamlearnCacheDataSuccess = 1
SteamlearnCacheDataErrorUnknownDataSource = 2
SteamlearnCacheDataErrorUncachedDataSource = 3
SteamlearnCacheDataErrorInvalidKeys = 4
SteamlearnCacheDataErrorForbidden = 5
SteamlearnCacheDataErrorInvalidTimestamp = 6
SteamlearnCacheDataDisabled = 7
Implementations
Sourceimpl ESteamLearnCacheDataResult
impl ESteamLearnCacheDataResult
Sourcepub fn is_valid(value: i32) -> bool
pub fn is_valid(value: i32) -> bool
Returns true if value is a variant of ESteamLearnCacheDataResult.
Sourcepub fn from_i32(value: i32) -> Option<ESteamLearnCacheDataResult>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<ESteamLearnCacheDataResult>
Use the TryFrom<i32> implementation instead
Converts an i32 to a ESteamLearnCacheDataResult, or None if value is not a valid variant.