pub struct CSvcMsgGameSessionConfiguration {Show 19 fields
pub is_multiplayer: Option<bool>,
pub is_loadsavegame: Option<bool>,
pub is_background_map: Option<bool>,
pub is_headless: Option<bool>,
pub min_client_limit: Option<u32>,
pub max_client_limit: Option<u32>,
pub max_clients: Option<u32>,
pub tick_interval: Option<u32>,
pub hostname: Option<String>,
pub savegamename: Option<String>,
pub s1_mapname: Option<String>,
pub gamemode: Option<String>,
pub server_ip_address: Option<String>,
pub data: Option<Vec<u8>>,
pub is_localonly: Option<bool>,
pub no_steam_server: Option<bool>,
pub is_transition: Option<bool>,
pub previouslevel: Option<String>,
pub landmarkname: Option<String>,
}Fields
is_multiplayer: Option<bool>is_loadsavegame: Option<bool>is_background_map: Option<bool>is_headless: Option<bool>min_client_limit: Option<u32>max_client_limit: Option<u32>max_clients: Option<u32>tick_interval: Option<u32>hostname: Option<String>savegamename: Option<String>s1_mapname: Option<String>gamemode: Option<String>server_ip_address: Option<String>data: Option<Vec<u8>>is_localonly: Option<bool>no_steam_server: Option<bool>is_transition: Option<bool>previouslevel: Option<String>landmarkname: Option<String>Implementations
Sourceimpl CSvcMsgGameSessionConfiguration
impl CSvcMsgGameSessionConfiguration
Sourcepub fn is_multiplayer(&self) -> bool
pub fn is_multiplayer(&self) -> bool
Returns the value of is_multiplayer, or the default value if is_multiplayer is unset.
Sourcepub fn is_loadsavegame(&self) -> bool
pub fn is_loadsavegame(&self) -> bool
Returns the value of is_loadsavegame, or the default value if is_loadsavegame is unset.
Sourcepub fn is_background_map(&self) -> bool
pub fn is_background_map(&self) -> bool
Returns the value of is_background_map, or the default value if is_background_map is unset.
Sourcepub fn is_headless(&self) -> bool
pub fn is_headless(&self) -> bool
Returns the value of is_headless, or the default value if is_headless is unset.
Sourcepub fn min_client_limit(&self) -> u32
pub fn min_client_limit(&self) -> u32
Returns the value of min_client_limit, or the default value if min_client_limit is unset.
Sourcepub fn max_client_limit(&self) -> u32
pub fn max_client_limit(&self) -> u32
Returns the value of max_client_limit, or the default value if max_client_limit is unset.
Sourcepub fn max_clients(&self) -> u32
pub fn max_clients(&self) -> u32
Returns the value of max_clients, or the default value if max_clients is unset.
Sourcepub fn tick_interval(&self) -> u32
pub fn tick_interval(&self) -> u32
Returns the value of tick_interval, or the default value if tick_interval is unset.
Sourcepub fn hostname(&self) -> &str
pub fn hostname(&self) -> &str
Returns the value of hostname, or the default value if hostname is unset.
Sourcepub fn savegamename(&self) -> &str
pub fn savegamename(&self) -> &str
Returns the value of savegamename, or the default value if savegamename is unset.
Sourcepub fn s1_mapname(&self) -> &str
pub fn s1_mapname(&self) -> &str
Returns the value of s1_mapname, or the default value if s1_mapname is unset.
Sourcepub fn gamemode(&self) -> &str
pub fn gamemode(&self) -> &str
Returns the value of gamemode, or the default value if gamemode is unset.
Sourcepub fn server_ip_address(&self) -> &str
pub fn server_ip_address(&self) -> &str
Returns the value of server_ip_address, or the default value if server_ip_address is unset.
Sourcepub fn data(&self) -> &[u8] ⓘ
pub fn data(&self) -> &[u8] ⓘ
Returns the value of data, or the default value if data is unset.
Sourcepub fn is_localonly(&self) -> bool
pub fn is_localonly(&self) -> bool
Returns the value of is_localonly, or the default value if is_localonly is unset.
Sourcepub fn is_transition(&self) -> bool
pub fn is_transition(&self) -> bool
Returns the value of is_transition, or the default value if is_transition is unset.
Sourcepub fn previouslevel(&self) -> &str
pub fn previouslevel(&self) -> &str
Returns the value of previouslevel, or the default value if previouslevel is unset.
Sourcepub fn landmarkname(&self) -> &str
pub fn landmarkname(&self) -> &str
Returns the value of landmarkname, or the default value if landmarkname is unset.
Sourcepub fn no_steam_server(&self) -> bool
pub fn no_steam_server(&self) -> bool
Returns the value of no_steam_server, or the default value if no_steam_server is unset.