pub struct CUserMessageSayText2 {
pub entityindex: Option<i32>,
pub chat: Option<bool>,
pub messagename: Option<String>,
pub param1: Option<String>,
pub param2: Option<String>,
pub param3: Option<String>,
pub param4: Option<String>,
}Fields
entityindex: Option<i32>chat: Option<bool>messagename: Option<String>param1: Option<String>param2: Option<String>param3: Option<String>param4: Option<String>Implementations
Sourceimpl CUserMessageSayText2
impl CUserMessageSayText2
Sourcepub fn entityindex(&self) -> i32
pub fn entityindex(&self) -> i32
Returns the value of entityindex, or the default value if entityindex is unset.
Sourcepub fn messagename(&self) -> &str
pub fn messagename(&self) -> &str
Returns the value of messagename, or the default value if messagename is unset.
Sourcepub fn param1(&self) -> &str
pub fn param1(&self) -> &str
Returns the value of param1, or the default value if param1 is unset.
Sourcepub fn param2(&self) -> &str
pub fn param2(&self) -> &str
Returns the value of param2, or the default value if param2 is unset.